@@ -11,7 +11,7 @@ pub enum Symbol {
 impl std::fmt::Display for Symbol {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match self {
-            Symbol::Lexeme(raw) => write!(f, "{raw:?}"),
+            Symbol::Lexeme(kind) => write!(f, "{kind:?}"),
             Symbol::Rule(rule) => write!(f, "{rule}"),
         }
     }
